from PyObjCTools.TestSupport import TestCase

import SafetyKit
import objc


class TestSACrashDetectionManager(TestCase):
    def test_protocols(self):
        self.assertProtocolExists("SACrashDetectionDelegate")

    def test_methods(self):
        self.assertResultIsBOOL(SafetyKit.SACrashDetectionManager.isAvailable)
        self.assertArgIsBlock(
            SafetyKit.SACrashDetectionManager.requestAuthorizationWithCompletionHandler_,
            0,
            b"v" + objc._C_NSInteger + b"@",
        )



from PyObjCTools.TestSupport import TestCase

import SafetyKit
import objc


class TestSAEmergencyResponseManagerHelper(SafetyKit.NSObject):
    def emergencyResponseManager_didUpdateVoiceCallStatus_(self, a, b):
        pass


class TestSAEmergencyResponseManager(TestCase):
    def test_protocols(self):
        self.assertProtocolExists("SAEmergencyResponseDelegate")

    def test_constants(self):
        self.assertIsEnumType(SafetyKit.SAEmergencyResponseManagerVoiceCallStatus)
        self.assertEqual(SafetyKit.SAEmergencyResponseManagerVoiceCallStatusDialing, 0)
        self.assertEqual(SafetyKit.SAEmergencyResponseManagerVoiceCallStatusActive, 1)
        self.assertEqual(
            SafetyKit.SAEmergencyResponseManagerVoiceCallStatusDisconnected, 2
        )
        self.assertEqual(SafetyKit.SAEmergencyResponseManagerVoiceCallStatusFailed, 3)

    def test_methods(self):
        self.assertArgIsBlock(
            SafetyKit.SAEmergencyResponseManager.dialVoiceCallToPhoneNumber_completionHandler_,
            1,
            b"vZ@",
        )

    def test_protocol_methods(self):
        self.assertArgHasType(
            TestSAEmergencyResponseManagerHelper.emergencyResponseManager_didUpdateVoiceCallStatus_,
            1,
            objc._C_NSInteger,
        )



# This file is generated by objective.metadata
#
# Last update: Wed Oct 19 11:29:47 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$SAErrorDomain$"""
enums = """$SAAuthorizationStatusAuthorized@2$SAAuthorizationStatusDenied@1$SAAuthorizationStatusNotDetermined@0$SACrashDetectionEventResponseAttempted@0$SACrashDetectionEventResponseDisabled@1$SAEmergencyResponseManagerVoiceCallStatusActive@1$SAEmergencyResponseManagerVoiceCallStatusDialing@0$SAEmergencyResponseManagerVoiceCallStatusDisconnected@2$SAEmergencyResponseManagerVoiceCallStatusFailed@3$SAErrorInvalidArgument@3$SAErrorNotAllowed@2$SAErrorNotAuthorized@1$SAErrorOperationFailed@4$"""
misc.update(
    {
        "SAEmergencyResponseManagerVoiceCallStatus": NewType(
            "SAEmergencyResponseManagerVoiceCallStatus", int
        ),
        "SAErrorCode": NewType("SAErrorCode", int),
        "SAAuthorizationStatus": NewType("SAAuthorizationStatus", int),
        "SACrashDetectionEventResponse": NewType("SACrashDetectionEventResponse", int),
    }
)
misc.update({})
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"NSObject",
        b"crashDetectionManager:didDetectEvent:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"emergencyResponseManager:didUpdateVoiceCallStatus:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"q"}},
        },
    )
    r(b"SACrashDetectionManager", b"isAvailable", {"retval": {"type": b"Z"}})
    r(
        b"SACrashDetectionManager",
        b"requestAuthorizationWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"q"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"SAEmergencyResponseManager",
        b"dialVoiceCallToPhoneNumber:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"Z"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



from PyObjCTools.TestSupport import TestCase

import SafetyKit


class TestSAError(TestCase):
    def test_constants(self):
        self.assertIsInstance(SafetyKit.SAErrorDomain, str)

        self.assertIsEnumType(SafetyKit.SAErrorCode)
        self.assertEqual(SafetyKit.SAErrorNotAuthorized, 1)
        self.assertEqual(SafetyKit.SAErrorNotAllowed, 2)
        self.assertEqual(SafetyKit.SAErrorInvalidArgument, 3)
        self.assertEqual(SafetyKit.SAErrorOperationFailed, 4)



from PyObjCTools.TestSupport import TestCase

import SafetyKit


class TestSAAuthorizationStatus(TestCase):
    def test_constants(self):
        self.assertIsEnumType(SafetyKit.SAAuthorizationStatus)
        self.assertEqual(SafetyKit.SAAuthorizationStatusNotDetermined, 0)
        self.assertEqual(SafetyKit.SAAuthorizationStatusDenied, 1)
        self.assertEqual(SafetyKit.SAAuthorizationStatusAuthorized, 2)



from PyObjCTools.TestSupport import TestCase

import SafetyKit


class TestSACrashDetectionEvent(TestCase):
    def test_constants(self):
        self.assertIsEnumType(SafetyKit.SACrashDetectionEventResponse)
        self.assertEqual(SafetyKit.SACrashDetectionEventResponseAttempted, 0)
        self.assertEqual(SafetyKit.SACrashDetectionEventResponseDisabled, 1)
